==> haskell-wai-app-file-cgi-3.1.10-209-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-file-cgi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-app-file-cgi
version:              3.1.10
visibility:           public
id:                   wai-app-file-cgi-3.1.10-7ZL9ZgDAZVl5NeSMLkEny0
key:                  wai-app-file-cgi-3.1.10-7ZL9ZgDAZVl5NeSMLkEny0
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/mighttpd/
synopsis:             File/CGI/Rev Proxy App of WAI
description:
    This WAI application library handles static files,
    executes CGI scripts, and serves as a reverse proxy
    (including EventSource).

category:             Web, Yesod
abi:                  df12dc4aec73604ce678f1d22cf5d3cd
exposed:              True
exposed-modules:      Network.Wai.Application.Classic
hidden-modules:
    Network.Wai.Application.Classic.CGI
    Network.Wai.Application.Classic.Conduit
    Network.Wai.Application.Classic.Def
    Network.Wai.Application.Classic.EventSource
    Network.Wai.Application.Classic.Field
    Network.Wai.Application.Classic.File
    Network.Wai.Application.Classic.FileInfo
    Network.Wai.Application.Classic.Header
    Network.Wai.Application.Classic.Lang
    Network.Wai.Application.Classic.Path
    Network.Wai.Application.Classic.Redirect
    Network.Wai.Application.Classic.Status
    Network.Wai.Application.Classic.Types
    Network.Wai.Application.Classic.RevProxy

import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-app-file-cgi-3.1.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-app-file-cgi-3.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-file-cgi
hs-libraries:         HSwai-app-file-cgi-3.1.10-7ZL9ZgDAZVl5NeSMLkEny0
depends:
    array-0.5.4.0 attoparsec-0.14.4-LhljGCg6FhTCY2JBHQACd0
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-GnsQmMXoRNL8LIaETetIqx
    conduit-1.3.6-3folGHzTKBNKhoMNony5kH
    conduit-extra-1.3.6-3tntNjfHSfUJoUejYufWcy containers-0.6.5.1
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp directory-1.3.6.2
    filepath-1.4.2.2 http-client-0.7.17-BwFPtRtRRT6E8bnhySQGTr
    http-conduit-2.3.8.3-G38UZharcPwFFoi2xy2v1G
    http-date-0.0.11-3ZDZ06aaVoF5PdQ7Pa9Ars
    http-types-0.12.4-1WvHfJfFYwEEMfNB6AwXxv
    mime-types-0.1.2.0-4X5b6Sz1aAM6TugVqfWYtQ
    network-3.1.4.0-9VcJfHdcvDFHTEtyJROzpl process-1.6.16.0
    sockaddr-0.0.1-Je3fBSFvsHDEuSrX9vupSQ
    static-hash-0.0.2-LZmQao6QYYdG6mUkVxJmL1 text-1.2.5.0
    transformers-0.5.6.2 unix-2.7.2.2 wai-3.2.4-BeEtgw0vkfmDPlBd8WCAFi
    wai-conduit-3.0.0.4-LLIW3lhSnkHJKNvSfP65fK
    warp-3.3.30-DdVSFB75L338yZl1awA7Xm
    word8-0.1.3-Bbsc0ZijkBHAg5mnae6Bis

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-file-cgi/html/wai-app-file-cgi.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-file-cgi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-file-cgi-3.1.10-210-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-file-cgi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-app-file-cgi
version:              3.1.10
visibility:           public
id:                   wai-app-file-cgi-3.1.10-BUiuqB4LHuuFIXlWeaArbg
key:                  wai-app-file-cgi-3.1.10-BUiuqB4LHuuFIXlWeaArbg
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/mighttpd/
synopsis:             File/CGI/Rev Proxy App of WAI
description:
    This WAI application library handles static files,
    executes CGI scripts, and serves as a reverse proxy
    (including EventSource).

category:             Web, Yesod
abi:                  ceeec8b915979c2c642002523a77e9d3
exposed:              True
exposed-modules:      Network.Wai.Application.Classic
hidden-modules:
    Network.Wai.Application.Classic.CGI
    Network.Wai.Application.Classic.Conduit
    Network.Wai.Application.Classic.Def
    Network.Wai.Application.Classic.EventSource
    Network.Wai.Application.Classic.Field
    Network.Wai.Application.Classic.File
    Network.Wai.Application.Classic.FileInfo
    Network.Wai.Application.Classic.Header
    Network.Wai.Application.Classic.Lang
    Network.Wai.Application.Classic.Path
    Network.Wai.Application.Classic.Redirect
    Network.Wai.Application.Classic.Status
    Network.Wai.Application.Classic.Types
    Network.Wai.Application.Classic.RevProxy

import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-app-file-cgi-3.1.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-app-file-cgi-3.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-file-cgi
hs-libraries:         HSwai-app-file-cgi-3.1.10-BUiuqB4LHuuFIXlWeaArbg
depends:
    array-0.5.4.0 attoparsec-0.14.4-LhljGCg6FhTCY2JBHQACd0
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-GnsQmMXoRNL8LIaETetIqx
    conduit-1.3.6-3folGHzTKBNKhoMNony5kH
    conduit-extra-1.3.6-3tntNjfHSfUJoUejYufWcy containers-0.6.5.1
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp directory-1.3.6.2
    filepath-1.4.2.2 http-client-0.7.17-BwFPtRtRRT6E8bnhySQGTr
    http-conduit-2.3.9-2ddZMpUn9VxJwOH0ADQXOV
    http-date-0.0.11-3ZDZ06aaVoF5PdQ7Pa9Ars
    http-types-0.12.4-1WvHfJfFYwEEMfNB6AwXxv
    mime-types-0.1.2.0-4X5b6Sz1aAM6TugVqfWYtQ
    network-3.1.4.0-9VcJfHdcvDFHTEtyJROzpl process-1.6.16.0
    sockaddr-0.0.1-Je3fBSFvsHDEuSrX9vupSQ
    static-hash-0.0.2-LZmQao6QYYdG6mUkVxJmL1 text-1.2.5.0
    transformers-0.5.6.2 unix-2.7.2.2 wai-3.2.4-BeEtgw0vkfmDPlBd8WCAFi
    wai-conduit-3.0.0.4-LLIW3lhSnkHJKNvSfP65fK
    warp-3.3.30-DdVSFB75L338yZl1awA7Xm
    word8-0.1.3-Bbsc0ZijkBHAg5mnae6Bis

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-file-cgi/html/wai-app-file-cgi.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-file-cgi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
